@@ -79,20 +79,20 @@ define([
                                                 if (msg.content['name'] == 'stderr') {
                                                     reject(msg);
                                                 } else {
-                                                    if (msg.content['text']) {
-                                                        result = String(msg.content['text']);
-                                                        type = 'text';
-                                                    } else if (msg.content.data) {
-                                                        if (msg.content.data['text/plain']) {
-                                                            result = String(msg.content.data['text/plain']);
-                                                            type = 'text/plain';
-                                                        } else if (msg.content.data['text/html']) {
+                                                    if (msg.content.data) {
+                                                        if (msg.content.data['text/html']) {
                                                             result = String(msg.content.data['text/html']);
                                                             type = 'text/html';
                                                         } else if (msg.content.data['image/png']) {
                                                             result = String(msg.content.data['image/png']);
                                                             type = 'image/png';
+                                                        } else if (msg.content.data['text/plain']) {
+                                                            result = String(msg.content.data['text/plain']);
+                                                            type = 'text/plain';
                                                         }
+                                                    } else if (msg.content['text']) {
+                                                        result = String(msg.content['text']);
+                                                        type = 'text';
                                                     }
                                                     resolve({result: result, type: type, msg: msg});
                                                 }
@@ -195,7 +195,7 @@ define([
                                         reject({result: output, type: 'error', msg: { content: { ename: output.ename, evalue: simpleEvalue, detail: convertedEvalue } }});
                                     } else {
                                         if (output.output_type === 'stream') {
-                                            result = String(output.text[0]);
+                                            result = String(output.text.join('\n'));
                                             type = 'text';
                                             msg = {
                                                 content: {
@@ -265,12 +265,12 @@ define([
                                             var message = content.text;    	    		    	    
                                             resolve({
                                                 result: message, 
-                                                type: type, 
+                                                type: 'text', 
                                                 msg: {
                                                     content: {
-                                                        name: type,
+                                                        name: 'text',
                                                         data: {
-                                                            [type]: message
+                                                            'text': message
                                                         }
                                                     }
                                                 }
@@ -315,13 +315,13 @@ define([
                                                 if (msg.content.data['image/png']) {
                                                     result = String(msg.content.data['image/png']);
                                                     type = 'image/png';
-                                                } else if (msg.content.data['text/plain']) {
-                                                    result = String(msg.content.data['text/plain']);
-                                                    type = 'text/plain';
                                                 } else if (msg.content.data['text/html']) {
                                                     result = String(msg.content.data['text/html']);
                                                     type = 'text/html';
-                                                }
+                                                } else if (msg.content.data['text/plain']) {
+                                                    result = String(msg.content.data['text/plain']);
+                                                    type = 'text/plain';
+                                                } 
                                             }
                                             resolve({result: result, type: type, msg: msg});
                                         } catch(ex) {
@@ -342,13 +342,13 @@ define([
                                                 if (msg.content.data['image/png']) {
                                                     result = String(msg.content.data['image/png']);
                                                     type = 'image/png';
-                                                } else if (msg.content.data['text/plain']) {
-                                                    result = String(msg.content.data['text/plain']);
-                                                    type = 'text/plain';
                                                 } else if (msg.content.data['text/html']) {
                                                     result = String(msg.content.data['text/html']);
                                                     type = 'text/html';
-                                                }
+                                                } else if (msg.content.data['text/plain']) {
+                                                    result = String(msg.content.data['text/plain']);
+                                                    type = 'text/plain';
+                                                } 
                                             }
                                             resolve({result: result, type: type, msg: msg});
                                         } catch(ex) {
@@ -654,13 +654,13 @@ define([
             });
         }
 
-        getDataList(dataTypeList=[], excludeList=[]) {
+        getDataList(dataTypeList=[], excludeList=[], allowModule=false) {
             // use function command to get variable list of selected data types
             var cmdSB = '_vp_print(_vp_get_variables_list(None))';
             if (!dataTypeList || dataTypeList.length <= 0) {
                 dataTypeList = [];
             }
-            cmdSB = com_util.formatString('_vp_print(_vp_get_variables_list({0}, {1}))', JSON.stringify(dataTypeList), JSON.stringify(excludeList));
+            cmdSB = com_util.formatString('_vp_print(_vp_get_variables_list({0}, {1}, {2}))', JSON.stringify(dataTypeList), JSON.stringify(excludeList), allowModule?'True':'False');
             
             var that = this;
             return new Promise(function(resolve, reject) {
@@ -914,7 +914,7 @@ define([
          * @param {String} configType vpudf, vpcfg 
          * @returns 
          */
-        setLabConfig(content, configType='vpudf') {
+        setLabConfig(content={}, configType='vpudf') {
             var that = this;
             var configFile = '';
             switch (configType) {
@@ -930,7 +930,7 @@ define([
             }
             // write file
             var sbfileSaveCmd = new com_String();
-            sbfileSaveCmd.appendFormat("_vp_set_lab_vpcfg('{0}', '{1}')", configFile, content);
+            sbfileSaveCmd.appendFormat("_vp_set_lab_vpcfg('{0}', {1})", configFile, content);
             return new Promise(function(resolve, reject) {
                 that.execute(sbfileSaveCmd.toString())
                 .then(function(resultObj) {
