@@ -165,10 +165,15 @@ define([
         var tblContent = $('<td></td>');
 
         
-        let { name, label, component, required } = obj;
+        let { name, label, component, required, output } = obj;
         let value = state[name];
         
-        var requiredFontStyle = required == true? 'vp-orange-text' : '';
+        var requiredFontStyle = '';
+        if (required === true) {
+            requiredFontStyle = 'vp-bold vp-orange-text';
+        } else if (output === true) {
+            requiredFontStyle = 'vp-bold';
+        }
         var lblTag = $(`<label class="vp-bold">${label}</label>`).attr({
             'for': name,
             'class': requiredFontStyle,
@@ -823,7 +828,7 @@ define([
      * @param {array/boolean} columnWithIndex boolean array or value to decide whether select tag has index option
      * Usage : 
      *  $(document).on('change', this.wrapSelector('#dataframe_tag_id'), function() {
-     *      pdGen.vp_bindColumnSource(that, 'dataframe_tag_id', ['column_input_id'], 'select', [true, true, true]);
+     *      pdGen.vp_bindColumnSource(that, 'dataframe_tag_id', ['column_input_id'], 'select', false, false);
      *  });
      */
     var vp_bindColumnSource = function(pageThis, targetId, columnInputIdList, tagType="input", columnWithEmpty=false, columnWithIndex=false) {
@@ -861,7 +866,7 @@ define([
         vpKernel.getColumnList(varName).then(function(resultObj) {
             try {
                 let { result, type, msg } = resultObj;
-                var varResult = JSON.parse(result);
+                var { list } = JSON.parse(result);
 
                 // check if it needs to add index option
                 let addIndex = false;
@@ -871,9 +876,9 @@ define([
                     addIndex = columnWithIndex;
                 }
                 if (addIndex == true) {
-                    varResult = [
+                    list = [
                         {value: varName + '.index', label: 'index'},
-                        ...varResult
+                        ...list
                     ]
                 }
 
@@ -885,9 +890,9 @@ define([
                     addEmpty = columnWithEmpty;
                 }
                 if (addEmpty == true) {
-                    varResult = [
+                    list = [
                         {value: '', label: 'Select option...'},
-                        ...varResult
+                        ...list
                     ]
                 }
 
@@ -903,7 +908,7 @@ define([
                         suggestInputX.setComponentID(columnInputId);
                         suggestInputX.addClass('vp-input vp-state');
                         suggestInputX.setPlaceholder("column name");
-                        suggestInputX.setSuggestList(function() { return varResult; }); //FIXME:
+                        suggestInputX.setSuggestList(function() { return list; }); //FIXME:
                         suggestInputX.setNormalFilter(false);
                         suggestInputX.setValue(defaultValue);
                         $(selector + ' #' + columnInputId).replaceWith(function() {
@@ -915,7 +920,7 @@ define([
                             'class': 'vp-select vp-state'
                         });
                         // make tag
-                        varResult.forEach(listVar => {
+                        list.forEach((listVar, idx) => {
                             var option = document.createElement('option');
                             $(option).attr({
                                 'value':listVar.value,
@@ -932,6 +937,7 @@ define([
                         $(pageThis.wrapSelector('#' + columnInputId)).replaceWith(function() {
                             return $(tag);
                         });
+                        $(pageThis.wrapSelector('#' + columnInputId)).trigger('change');
                     }
                 }).catch(function(err) {
                     vpLog.display(VP_LOG_TYPE.ERROR, 'com_generator - bindColumnSource error ', err)
